# rmtoo-art-prio-lists

NAME
DESCRIPTION
SELECTED FOR SPRINT
ASSIGNED
BACKLOG
REQUIREMENTS ELABORATION LIST
PRIORITY LISTS
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-prio-lists - requirements management tool: priority lists.

## DESCRIPTION

The rmtoo requirment management tool is able to manage some output lists:

## SELECTED FOR SPRINT

The table Selected for Sprint contains all these requirements which should be finished within the next (current) sprint. When a requirement has the class ’selected’ it will be listed here.

## ASSIGNED

The selected requirements can be assigned to developers. All assigned requirements will appear in this table.

## BACKLOG

One list is the so called Backlog. A term which is usually used in SCRUM. The Backlog is the list of implementable requirements sorted by the importance: the most important are at the beginning.

## REQUIREMENTS ELABORATION LIST

The requirements elaboration list is mostly the same as the backlog but for the requirements writer(s). This list contains all the requirements which are not (yet) implementable, i.e. the requirements which reflect some idea which must be detailed.

## PRIORITY LISTS

Those two lists are more or less the ToDo lists for the developers (backlog) and the requirements writes (requirements elaboration list). They can (and should) start at the top of the list where the most important and necessary things are listed.

Both lists contain also the sum of all entries up to a certain point. Therefore it is very easy to get information like: it will take N effort points to finish work on all most important things (level 10 requirements).

## CONFIGURATION

The name must be set to prios. The following parameters must be available:

output_filename The parameter is the name of the file where the priority lists will be stored.

start_date The date when the project starts. The format must be YYYY-MM-DD. If this is not specified, yesterday is assumed.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010-2011 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later